﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace SelectedRowItem
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }
    }
    public class ViewModel
    {
        private ObservableCollection<Product> _products;
        public ObservableCollection<Product> Products
        {
            get
            {
                if (_products == null)
                    InitCustomProducts();
                return _products;
            }
        }
        private void InitCustomProducts()
        {
            _products = new ObservableCollection<Product>();
            for (int i = 0; i < 100; i++)
            {
                _products.Add(new Product());
            }
        }
        public ICommand DisplaySelectedItemCommand
        {
            get;set;
        }
        public ViewModel()
        {
            DisplaySelectedItemCommand = new RelayCommand(ExecuteMyMethod, CanExecuteMyMethod);
        }
        private bool CanExecuteMyMethod(object parameter)
        {
            if (parameter != null && parameter.GetType() == typeof(Product))
                return true;
            else
                return false;
        }

        private void ExecuteMyMethod(object parameter)
        {
            Product selectedRowItem = parameter as Product;
            MessageBox.Show($"SelectedItem Info: \n{selectedRowItem.Name}, {selectedRowItem.Color}, {selectedRowItem.Line}, {selectedRowItem.Price}");
        }
    }
    public class Product
    {
        static Random _rnd = new Random();
        static string[] _names = "Macko|Surfair|Pocohey|Studeby".Split('|');
        static string[] _lines = "Computers|Washers|Stoves|Cars".Split('|');
        static string[] _colors = "Red|Green|Blue|White".Split('|');
        static string[] _priorities = "Low|Medium|High".Split('|');

        public string Name { get; set; }
        public string Color { get; set; }
        public string Line { get; set; }
        public double Price { get; set; }
        public double Cost { get; set; }
        public DateTime Introduced { get; set; }
        public bool Discontinued { get; set; }
        public int Priority { get; set; }
        public Product()
        {
            Name = _names[_rnd.Next() % _names.Length];
            Line = _lines[_rnd.Next() % _lines.Length];
            Color = _colors[_rnd.Next() % _colors.Length];
            Price = 30 + _rnd.NextDouble() * 1000;
            Cost = 3 + _rnd.NextDouble() * 300;
            Discontinued = _rnd.NextDouble() < .2;
            Introduced = DateTime.Today.AddDays(_rnd.Next(-600, 0));
            Priority = _rnd.Next(0, 3);
        }
    }
    public class RelayCommand : ICommand
    {
        Action<object> _executeMethod;
        Func<object, bool> _canexecuteMethod;


        public RelayCommand(Action<object> executeMethod, Func<object, bool> canexecuteMethod)
        {
            _executeMethod = executeMethod;
            _canexecuteMethod = canexecuteMethod;
        }

        public bool CanExecute(object parameter)
        {
            if (_canexecuteMethod != null)
            {
                return _canexecuteMethod(parameter);
            }
            else
            {
                return false;
            }
        }

        public event EventHandler CanExecuteChanged {
            add
            {
                CommandManager.RequerySuggested += value;
            }
            remove
            {
                CommandManager.RequerySuggested -= value;
            }
        }

        public void Execute(object parameter)
        {
            _executeMethod(parameter);
        }
    }
}
